Exception: Dreck::AbsorptionError

Inherits:
DreckError
  • Object
show all
Defined in:
lib/dreck/exceptions.rb

Overview

Raised during argument absorption if arguments are either left over or are insufficient to populate the expected results.

Instance Method Summary collapse

Constructor Details

#initialize(actual, expected) ⇒ AbsorptionError

Returns a new instance of AbsorptionError.

Parameters:

  • actual (Integer)

    the actual number of arguments given

  • expected (Integer)

    the expected number of arguments



18
19
20
21
# File 'lib/dreck/exceptions.rb', line 18

def initialize(actual, expected)
  nmany = actual < expected ? "too few" : "too many"
  super "#{nmany} arguments given (#{actual}, expected #{expected})"
end